/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include "stdio_user.h"
#include <stdio.h>

#if CY_BLE_HOST_CORE   
/******************************************************************************
* Macros
*******************************************************************************/
#define ENABLE      (1u)
#define DISABLE     (0u)

#define DEBUG_BLE_ENABLE    DISABLE

#if DEBUG_BLE_ENABLE
#define DEBUG_BLE       printf
#else
#define DEBUG_BLE(...)
#endif

/* Array to hold whitelist address
 * Each array element has a format - {{Device Addrress},Adress type}
 * The First Element is initialized with Device address = 0x00A500B2A230,Address type = CYBLE_GAP_ADDR_TYPE_PUBLIC
 * Rest of the elements can be initialized to support other addresses    */

cy_stc_ble_gap_bd_addr_t WhitelistDevice[16] = { {{0x30,0xA2,0xB2,0x00,0xA5,0x00},CY_BLE_GAP_ADDR_TYPE_PUBLIC},  
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                           {{0x00,0x00,0x00,0x00,0x00,0x00},0},
                                          };
cy_en_ble_api_result_t apiResult;
/*******************************************************************************
*        Function Prototypes
*******************************************************************************/
void Ble_Init(void);
void StackEventHandler(uint32 event, void* eventParam);

/*******************************************************************************
* Function Name: HostMain()
********************************************************************************
* Summary:
*  Main function for the BLE Host.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Theory:
*  The function starts BLE and UART components.
*  This function processes all BLE events
*
*******************************************************************************/
int HostMain(void)
{
    __enable_irq(); /* Enable global interrupts. */
    
    UART_Start();
    /* \x1b[2J\x1b[;H - ANSI ESC sequence for clear screen */
    printf("\x1b[2J\x1b[;H");
    
     printf("***************** PSoC6 BLE Constant Broadcaster project *******"\
               "**********\r\n");
    /* Initialize BLE */
    Ble_Init();
    
    for(;;)
    {
        /* Cy_Ble_ProcessEvents() allows BLE stack to process pending events */
        Cy_BLE_ProcessEvents();
    }
}

/*******************************************************************************
* Function Name: Ble_Init()
********************************************************************************
*
* Summary:
*   This function initializes BLE.
*
* Return:
*   None
*
*******************************************************************************/
void Ble_Init(void)
{
    cy_stc_ble_stack_lib_version_t stackVersion;
    
    /* Start Host of BLE Component and register generic event handler */
    apiResult = Cy_BLE_Start(StackEventHandler);
    
    if(apiResult != CY_BLE_SUCCESS)
    {
        printf("Cy_BLE_Start API Error: %x \r\n", apiResult);
    }
    else
    {
        printf("BLE Stack Initialized...\r\n");
    }
    
    apiResult = Cy_BLE_GetStackLibraryVersion(&stackVersion);
    
    if(apiResult != CY_BLE_SUCCESS)
    {
        printf("Cy_BLE_GetStackLibraryVersion API Error: 0x%2.2x \r\n",\
                  apiResult);
    }
    else
    {
        printf("Stack Version: %d.%d.%d.%d \r\n", stackVersion.majorVersion, 
        stackVersion.minorVersion, stackVersion.patch, stackVersion.buildNumber);
    }
    
}

/*******************************************************************************
* Function Name: StackEventHandler()
********************************************************************************
*
* Summary:
*   This is an event callback function to receive events from the BLE Component.
*
*  event - the event code
*  *eventParam - the event parameters
*
* Return:
*   None
*
*******************************************************************************/
void StackEventHandler(uint32 event, void* eventParam)
{
    switch(event)
    {
        /**********************************************************
        *                       General Events
        ***********************************************************/
        /* This event is received when the BLE component is Started */
        case CY_BLE_EVT_STACK_ON:
        {
            printf("CY_BLE_EVT_STACK_ON, Start Advertisement \r\n");    
         
            /* Enter into discoverable mode so that remote device can search it */
            Cy_BLE_GAPP_StartAdvertisement(CY_BLE_ADVERTISING_FAST,
                                   CY_BLE_BROADCASTER_CONFIGURATION_0_INDEX);
            
            /* Adding device address to the whitelist */
            apiResult = Cy_BLE_AddDeviceToWhiteList(&WhitelistDevice[0]);
            
            printf("\r\n API result of Cy_BLE_AddDeviceToWhiteList function is %x \r\n", apiResult);   
            
            break;
        }    
        
        /* This event is received when there is a timeout. */
        case CY_BLE_EVT_TIMEOUT:
        {
			DEBUG_BLE("CY_BLE_EVT_TIMEOUT \r\n"); 
            
            break;
		}  
        
        /* This event indicates that some internal HW error has occurred. */    
		case CY_BLE_EVT_HARDWARE_ERROR:    
        {
			DEBUG_BLE("Hardware Error \r\n");
            
			break;
		}
        
        /**********************************************************
        *                       GAP Events
        ***********************************************************/
       
        /* This event indicates peripheral device has started/stopped
           advertising. */
        case CY_BLE_EVT_GAPP_ADVERTISEMENT_START_STOP:
        {
            DEBUG_BLE("CY_BLE_EVT_GAPP_ADVERTISEMENT_START_STOP: ");
            break;
        }
        default:
           break;
    }
}

#endif /* CY_BLE_HOST_CORE */

/* [] END OF FILE */
